Reference for database/application structures — Signalbox 2 documentation

### Navigation

- index
- next |
- previous |
- Signalbox 2 documentation »

# Reference for database/application structures

## Ask application

### Models

### Types of questions (Field classes)

SignalboxField stores the additional information signalbox needs to properly display and process questions.

### Notes on all question types

- Question text: this is displayed in syntax (see `../markdown`).

..warning:: Note that some characters are stripped and used to format the question text in html – for example, text surrounded by two * characters will be italicised, and lines starting with a number and a period (e.g. “1. ”) will be turned into a numbered list.

### Types of question

Each of the following question classes extends the standard django form fields to allow for different types of questions:

## Signalbox application

### Models

### Navigation

- index
- next |
- previous |
- Signalbox 2 documentation »